@@ -302,23 +302,36 @@ In case the service has been recently started please wait 5 minutes for it to be
             if self._debug:
                 print("Unexpected exception: ", ex)
 
-    def submit_job(self, *, backend=None, circuit=None, circuits=None, shots=None, comments=""):
+    def submit_job(
+        self, *, backend=None, circuit=None, circuits=None, shots=None, comments=""
+    ):
         if not self._verify_user_is_authenticated():
             return
         if not backend:
             print("Please specify the backend name.")
             return
         if circuit is None and circuits is None:
-            print("An quantum circuit to be executed or a list of quantum circuits to be executed must be specified.")
+            print(
+                "An quantum circuit to be executed or a list of quantum circuits to be executed must be specified."
+            )
             return
         if circuit is not None and circuits is not None:
-            print("You can use either 'circuit' or 'circuits' as input arguments but not both at the same time.")
+            print(
+                "You can use either 'circuit' or 'circuits' as input arguments but not both at the same time."
+            )
             return
         if circuit is not None and not isinstance(circuit, QuantumCircuit):
-            print("The circuit must be an instance of QuantumCircuit.")
+            print(
+                "The 'circuit' argument must be an instance of QuantumCircuit or deriving from it."
+            )
             return
-        if not isinstance(circuits, list) or not all(isinstance(circ, QuantumCircuit) for circ in circuits):
-            print("The circuits must be a list of QuantumCircuit instances.")
+        if circuits is not None and (
+            not isinstance(circuits, list)
+            or not all(isinstance(circ, QuantumCircuit) for circ in circuits)
+        ):
+            print(
+                "The 'circuits' argument must be a list of QuantumCircuit instances or objects deriving from QuantumCircuit."
+            )
             return
         if shots is None:
             print("Please specify the number of shots.")
